@@ -59,14 +59,14 @@ RETRIES = 3
 MAX_WORKERS = 8
 MAX_ELEMS = 10
 MEGABYTES = 1024 * 1024
-MAX_BYTES = 1.2 * MEGABYTES
+MAX_BYTES = 2.4 * MEGABYTES
 MAX_PAYLOAD = 15 * MEGABYTES
 DEFAULT_HOST = "contribs-api.materialsproject.org"
 BULMA = "is-narrow is-fullwidth has-background-light"
 PROVIDERS = {"github", "google", "facebook", "microsoft", "amazon"}
 COMPONENTS = ["structures", "tables", "attachments"]  # using list to maintain order
 SUBDOMAINS = ["contribs", "lightsources", "ml", "workshop-contribs"]
-PORTS = [5000, 5002, 5003, 5005, 10000, 10002, 10003, 10005]
+PORTS = [5000, 5002, 5003, 5005, 10000, 10002, 10003, 10005, 20000]
 HOSTS = ["localhost", "contribs-apis"]
 HOSTS += [f"192.168.0.{i}" for i in range(36, 47)]  # PrivateSubnetOne
 HOSTS += [f"192.168.0.{i}" for i in range(52, 63)]  # PrivateSubnetTwo
@@ -298,7 +298,7 @@ class Table(pd.DataFrame):
         """Show summary info for table"""
         info = Dict((k, v) for k, v in self.attrs.items())
         info["columns"] = ", ".join(self.columns)
-        info["nrows"] = len(self.index)
+        info["nrows"] = len(self.total_data_rows)
         return info
 
 
@@ -726,6 +726,29 @@ class Client(SwaggerClient):
 
         return Dict(self.projects.get_entry(pk=name, _fields=["_all"]).result())
 
+    def create_project(self, name: str, title: str, authors: str, description: str, url: str):
+        """Create a project
+
+        Args:
+            name (str): unique name matching `^[a-zA-Z0-9_]{3,31}$`
+            title (str): unique title with 5-30 characters
+            authors (str): comma-separated list of authors
+            description (str): brief description (max 1500 characters)
+            url (str): URL for primary reference (paper/website/...)
+        """
+        queries = [{"name": name}, {"title": title}]
+        for query in queries:
+            if self.get_totals(query=query, resource="projects")[0]:
+                logger.error(f"Project with {query} already exists!")
+                return
+
+        project = {
+            "name": name, "title": title, "authors": authors, "description": description,
+            "references": [{"label": "REF", "url": url}]
+        }
+        owner = self.projects.create_entry(project=project).result().get("owner")
+        logger.info(f"Project `{name}` created with owner `{owner}`")
+
     def get_contribution(self, cid: str) -> Type[Dict]:
         """Retrieve full contribution entry
 
@@ -1011,6 +1034,7 @@ class Client(SwaggerClient):
         Args:
             query (dict): query to select resource entries
             timeout (int): cancel remaining requests if timeout exceeded (in seconds)
+            resource (str): type of resource
             op (str): operation to calculate total pages for, one of
                       ("get", "create", "update", "delete", "download")
 
@@ -1403,7 +1427,9 @@ class Client(SwaggerClient):
             query["project"] = self.project
 
         try:
-            resp = self.projects.get_entry(pk=query["project"], _fields=["is_public"]).result()
+            resp = self.projects.get_entry(
+                pk=query["project"], _fields=["is_public", "is_approved"]
+            ).result()
         except HTTPNotFound:
             return {"error": f"project `{query['project']}` not found or access denied!"}
 
@@ -1413,6 +1439,9 @@ class Client(SwaggerClient):
         ret = {}
 
         if resp["is_public"] != is_public:
+            if is_public and not resp["is_approved"]:
+                return {"error": f"project `{query['project']}` is not approved yet!"}
+
             resp = self.projects.update_entry(
                 pk=query["project"], project={"is_public": is_public}
             ).result()
@@ -1445,8 +1474,7 @@ class Client(SwaggerClient):
             "identifier": "mp-4",
             "data": {
                 "a": "3 eV",
-                "b": {"c": "hello", "d": 3},
-                "d.e.f": "nest via dot-notation"
+                "b": {"c": "hello", "d": 3}
             },
             "structures": [<pymatgen Structure>, ...],
             "tables": [<pandas DataFrame>, ...],
